@@ -114,13 +114,12 @@ void gptimer_init(ambapp_core *core, int level)
 #endif
 }
 
-static int apbuart_initied = 0;
+static int apbuart_initied = CONFIG_UART_INDEX + 1;
 
 /* Find first APBUART for console */
 void apbuart_init(ambapp_core *core, int level)
 {
-	if (!apbuart_initied && core->apbslv) {
-		apbuart_initied = 1;
+	if (apbuart_initied != 0 && (--apbuart_initied == 0) && core->apbslv) {
 		apbuart = (struct apbuart_regs *)core->apbslv->address;
 	}
 }
